do Z:\greek\do\directories.do
cd $dir_dta
capture log close
log using $dir_log\rd_lr, replace
set matsize 5000

********************************************************************************
/*This do file replicates Table 8 and the core results of Table 9 from Even 
and Smith. The bounding exercise for Table 9 is executed in bounding.do.  */ 
			
********************************************************************************
use ${dir_dta}\merged_sum_wint_by_stdnt_w_salary.dta, clear
drop if inelig_ch ==1
keep if enteringsem>="201010" /*just keep RD sample*/ 
drop if intl ==1 /*drop international students */

gen grad_3point = grad_gpa>=3 if grad_gpa!=.
gen cohort = substr(enteringsem, 1, 4) /*creating a new variable for year entered*/
destring cohort, replace
gen final_3point = final_gpa>=3

global rd_vars grade normgrade withdraw evergreek pledge1 eligible1a eligible1b eligible1c ///
center_gpa1a center_gpa1b center_gpa1c center_gpa_inter1a center_gpa_inter1b center_gpa_inter1c

global lab_outcome "employed fulltime salary_midpt lnsal_hat_grad_maj"
global educ_outcome "retention fouryr_grad fiveyr_grad sixyr_grad grad_gpa final_gpa gpa_norm grad_3point final_3point same_major awstem enrolled_grad" 
global educ_controls "female bestact dom_min enteringage resident need_hi_med"
global lab_other "degree_fall degree_spring degree_winter degree_summer enter_div enter_area infield hourly ft_stat log_sal high_sal grad_universe sal_resp emp_resp survey_year"

egen num_sem = count(exper), by(dummyid)
label var num_sem "number of semesters student present in sample"
	
collapse num_sem pledge1 eligible1c center_gpa1c center_gpa_inter1c cohort enrolled_undergrad $lab_outcome $educ_outcome $educ_controls $lab_other, by(dummyid)  /*collapse data to the individual level*/


********************************************************************************	
/*Table 8. RD Estimates of the Effect of Greek Affiliation on Long-run 
educational outcomes */
********************************************************************************
	
	foreach var of varlist $educ_outcome {
	*BW of 0.4 w/controls
	ivreg2 `var' (pledge1=eligible1c) center_gpa1c center_gpa_inter1c i.cohort $educ_controls if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), cluster(center_gpa1c)
	eststo `var'_iv_40	
	}
	
esttab retention_iv_40 fouryr_grad_iv_40 fiveyr_grad_iv_40 sixyr_grad_iv_40 grad_gpa_iv_40 final_gpa_iv_40 grad_3point_iv_40 final_3point_iv_40 same_major_iv_40 awstem_iv_40  enrolled_grad_iv_40 using ${dir_results}\rd_regs_lr_ed_40.rtf, se(3) star(* .10 ** .05 *** .01)  ///
	replace ///
	title("RD Estimates of Greek Affiliation on Long-run Educational Outcomes") ///
	keep(*pledge*) 


	
********************************************************************************
*Table 9. LR Labor market outcomes
********************************************************************************
	
global emp_controls "female bestact dom_minor resident need_hi_med enteringage i.survey_year degree_fall degree_spring degree_winter degree_summer"
*OLS preliminary analysis
	*OLS using all data
	reg log_sal pledge1 $emp_controls, robust
	gen samp = e(sample)
	eststo log_sal_OLS1
	estadd local ftime "No"
	estadd local entdiv "No"	

*Add control for entering division of major
global emp_controls "female bestact dom_minor resident need_hi_med enteringage i.survey_year degree_fall degree_spring degree_winter degree_summer i.enter_area"
	reg log_sal pledge1 $emp_controls, robust
	eststo log_sal_OLS2
	estadd local ftime "No"
	estadd local entdiv "Yes"
/*restrict to full-time employees, not enrolled in continuing education*/ 
	reg log_sal pledge1 $emp_controls if enrolled_grad !=1 & enrolled_undergrad !=1 & ft_stat ==1, robust
	eststo log_sal_OLS_3
	estadd local ftime "Yes"
	estadd local entdiv "Yes"	
	
/*further restrict to within main bandwidth*/
	reg log_sal pledge1 $emp_controls if enrolled_grad !=1 & enrolled_undergrad !=1 & ft_stat ==1 & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), robust
	eststo log_sal_OLS_4
	estadd local ftime "Yes"
	estadd local entdiv "Yes"

global lab_outcome_fullsam "lnsal_hat_grad_maj"
foreach var of varlist $lab_outcome_fullsam {
	*BW of 0.4 w/controls
	ivreg2 `var' (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $emp_controls if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), cluster(center_gpa1c)
	eststo `var'_iv_40	
	}

global lab_outcome_unenrolled "employed fulltime"
foreach var of varlist $lab_outcome_unenrolled {
	*BW of 0.4 w/controls
	ivreg2 `var' (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $emp_controls if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40) & enrolled_grad !=1 & enrolled_undergrad !=1, cluster(center_gpa1c)
	eststo `var'_iv_40	
	}	


global sal_out "log_sal"
foreach var of varlist $sal_out {
	*BW of 0.4 w/controls
	ivreg2 `var' (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $emp_controls if enrolled_grad !=1 & enrolled_undergrad !=1 & ft_stat ==1 & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), cluster(center_gpa1c)
	eststo `var'_iv_40	
	}	

/* Employment survey respondent*/	
reg emp_resp eligible1c center_gpa1c center_gpa_inter1c $emp_controls if enrolled_grad !=1 & enrolled_undergrad !=1 & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), cluster(center_gpa1c)	
eststo emp_resp_40	

	
/*Salary survey respondent*/
reg sal_resp eligible1c center_gpa1c center_gpa_inter1c $emp_controls if enrolled_grad !=1 & enrolled_undergrad !=1 & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40), cluster(center_gpa1c)	
eststo sal_resp_40

esttab emp_resp_40 employed_iv_40 fulltime_iv_40 sal_resp_40 log_sal_OLS_3 log_sal_iv_40 lnsal_hat_grad_maj_iv_40 using ${dir_results}\rd_regs_employ.rtf, se(3) star(* .10 ** .05 *** .01)  ///
	replace ///
	title("RD Estimates of Greek Affiliation on Labor Market Outcomes") ///
	keep(*pledge* eligible1c*) 

capture log close	
	
	
	
	
