do Z:\greek\do\directories.do
cd $dir_dta
capture log close
log using $dir_log\rd, replace


********************************************************************************
/*This do file replicates Tables 2 and 3 from Even and Smith */ 
			
********************************************************************************
use ${dir_dta}\merged_sum_wint.dta, clear
drop if inelig_ch ==1
drop if intl ==1
drop if summer ==1 | winter ==1


********************************************************************************
********************************************************************************
	/*Restrict to period where GPA requirements are strongly enforced (2010+)*/
********************************************************************************
********************************************************************************
global controls "bestact female dom_minor resident need_hi_med enteringage i.exper i.hterm"
keep if enteringsem>="201010" /*restrict to period where GPA req in effect*/

gen wdf_grade = 0
replace wdf_grade = 1 if withdraw ==1 | d_grade ==1 | f_grade==1
label var wdf_grade "Course ends in withdraw, fail, or D"

gen ab_grade = b_grade==1 | a_grade==1
label var ab_grade "Course grade of an A or B"

gen joined = grk_pledge+grk_active+grk_susp_midsem+grk_susp_ongoing+grk_rem+grk_left
label var joined "=1 if joined this semester or anytime prior"


************************************************************
/* Table 2. Discontinuities in observable characteristics
Test Validity of RD - Discontinuities in other variables
a) bestact equivalent
b) minority
c) High or Medium financial need
d) State resident (in-state)
e) age at entry
f) withdrawals during semester 1
g) First-Sem Credit Hours Earned
h) First-Semester Course Level
i) Course-Section Average Grade
************************************************************ */

preserve
	keep if enteringsem>="201010"
	global spec_check bestact female dom_min dom_non enteringage resident need_hi_med need_grant_need
	collapse pledge1 $spec_check eligible1c center_gpa1c center_gpa_inter1c if normgrade!=., by(dummyid)  /*collapse data to the individual level*/

	forvalues bw= 30(5)40 {
	foreach var of varlist $spec_check {
		reg `var' eligible1c center_gpa1c center_gpa_inter1c if center_gpa1c >=float(-.`bw') & center_gpa1c<=float(.`bw'), cluster(center_gpa1c)
		eststo `var'_`bw'
		sum `var' if e(sample)==1
		estadd scalar mn=r(mean)
		}	
		}
		
restore

*f-i) withdrawals, completed credits, course average during semester 1, course level (fresh, soph, jun, senior etc.)
preserve
	keep if enteringsem>="201010" & exper ==0 /*looking at withdrawal rate in sem 1 only*/
	collapse eligible1c center_gpa1c center_gpa_inter1c attempt_credit complete_credit courselevel courseavg (max) withdraw, by(dummyid)  /*collapse data to the individual level for sem 1*/
	global if_state "if center_gpa1c >=float(-.4) & center_gpa1c<=float(.4)"
	forvalues bw= 30(5)40 {
	foreach var of varlist withdraw attempt_credit complete_credit courselevel courseavg {
	reg `var' eligible1c center_gpa1c center_gpa_inter1c if center_gpa1c >=float(-.`bw') & center_gpa1c<=float(.`bw'), cluster(center_gpa1c)
		eststo `var'_`bw'
		sum `var' if e(sample)==1
		estadd scalar mn=r(mean)
		}
		}
restore


esttab bestactequivalent_40 dom_minor_40 need_hi_med_40 resident_40 enteringage_40 withdraw_40 complete_credit_40 courselevel_40 courseavg_40   using ${dir_results}\rd_regs_falsification.rtf, se(3) b(3) star(* .10 ** .05 *** .01)  ///
	replace mtitles("Best ACT Equivalent" "Domestic Minority" "Medium or High Financial Need" "State Resident" "Age at Entry" "Withdraw from Any Course" "Course Credits Completed" "Level of Course" "Average Grade for Course") ///
	title("Table 2. Discontinuities in Observable Characteristics") ///
	keep(*eligible*) scalars(mn) 




**********************************************************
* Table 3. RD Estimates of Greek Affiliation on Course Grades and Selection 
**********************************************************

/***************************************
Main Table Outcomes considered: 
Norm Grade (controls)
*Using augmented local linear regression a la hausman and rapson
Grade point (non-normalized)
Grade of A/B
Grade of C
Grade of D, F or withdrawal
Level of course
Avg course grade excluding own grade
**************************************/


*Col 1: Normalized course grades
ivreg2 normgrade (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $controls [aw=credithours] if center_gpa1c >=float(-0.4) & center_gpa1c<=float(0.4) & exper >=1 & exper<12 & enteringsem>="201010", cluster(center_gpa1c)
outreg2 using ${dir_results}\rd_course_out.rtf, replace adds(First Stage F-stat, `e(rkf)') keep(pledge1)

********************************************************************************
/* Use augmented local linear a la Hausman and Rapson 2018 for columns 2-5*/
********************************************************************************
save c:\temp.dta, replace
use c:\temp.dta, clear
do Z:\greek\do\analysis\rdfe_program
set seed 7879

global bw=40 
global i 0
foreach y  in  grade ab_grade c_grade wdf_grade {
global i 0
global y "`y'"
capture log close
log using Z:\greek\log\reg${y}_bw${bw}.smcl, replace
global controls_rdfe "bestact female dom_minor resident need_hi_med enteringage"
    display "$S_TIME"
capture erase c:\out_$y_$bw.dta
bootstrap rdfe _b, reps(200) saving(c:\out_$y_$bw.dta)  cluster(dummyid) dots  noisily 
outreg2 using ${dir_results}\rd_course_out.rtf, append
}

reghdfe wdf_grade $controls_rdfe [aw=credithours], absorb(FE_course=courseid FE_exper=i.exper) cluster(center_gpa1c)
gen rd_samp = e(sample)
global course_out courselevel courseavg_i
	foreach var of varlist $course_out {
		ivreg2 `var' (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $controls [aw=credithours] if center_gpa1c >=float(-0.40) & center_gpa1c<=float(0.40) & exper >=1 & exper<12 & enteringsem>="201010" & rd_samp==1, cluster(center_gpa1c)
outreg2 using ${dir_results}\rd_course_out.rtf, append
		}	


   
capture log close   
