/*==================================================================================
THIS DO FILE CREATES THE FOLLOWING:
FIGURES 3 & 4
TABLES 4, 5, 6, 7
Appendix table A8
==================================================================================*/
do z:\greek\do\directories.do
cd $dir_dta
capture log close
log using $dir_log\regs, replace
set matsize 5000
global dir_results "$dir_results"
do "${dir_do}\graph_settings.do"

/*==================================================================================
					DATA & GLOBAL CREATION
==================================================================================*/
use "${dir_dta}\merged_sum_wint", clear
drop if intl==1
*drop if inelig_ch ==1
drop if bestactequivalent==.
drop if summer==1 | winter==1


gen cum_gpa_sem1=cum_gpa_sem1c  /*using summer/winter update of gpa for all students*/
gen eligible_sem1=inelig_ch==0 & cum_gpa_sem1>=2.5 & cum_gpa_sem1~=.
label variable eligible_sem1 "dv=1 if gpa_sem1>=2.5 & 12 or more credithours"

cd ${dir_results}

global grk_vars1 			grk_active grk_susp_midsem grk_susp_ongoing grk_rem grk_left 
gen sibs_course=nsibs_course>0
gen sibs_major=nsibs_major>0
egen nsibs_course_cat=cut(nsibs_course), at(0,1,2,4,100)
gen dry=chapter==37 & qterm>=yq(2009,1)  
global x i.exper 

gen grk=grk_pledge+grk_active+grk_susp_midsem+grk_susp_ongoing+grk_rem+grk_left
gen grk_former=grk-grk_pledge-grk_active
global grk_x "grk_pledge grk_active grk_former"
global grk_vars  grk_pledge grk_active grk_former

gen x=cum_gpa if exper==2 
bysort dummyid: egen cum_gpa_sem3=mean(x)
label variable cum_gpa_sem3 "cum gpa in fall semester of sopohomore year"
drop x

save "${dir_dta}\temp.dta", replace

use "${dir_dta}\temp.dta", clear


/*==================================================================================
FIGURE 3.   GRADE PROFILES OF GREEK VS NON-GREEK

==================================================================================*/
preserve
	collapse (mean) grade normgrade (count) num_obs=grade [aweight= credithour], by(evergreek exper)
	graph twoway (scatter grade exper if exper <=7 & evergreek ==1,  connect(1) lpattern(dash)) ///
	(scatter grade exper if exper <=7 & evergreek ==0,  connect(1)), ///
	ytitle("GPA") xtitle("Semesters of experience") legend(label(1 "Ever-Greek") label(2 "Never-Greek")) ///
	title("GPA Profile: Full Sample")  note("weighted by credit hour") 
	graph export ${dir_gph}\exper_profile.pdf, replace
	graph save ${dir_gph}\exper_profile, replace
	gen samp = .
	replace samp = 1 if evergreek ==1 
	replace samp = 2 if evergreek ==0
	label var samp "Description of sample - Greek X GPA req"
	label define samplbl 1 "Ever-Greek: full" 2 "Never-Greek: full" 3 "Ever-Greek: 2.5+" 4 "Never-Greek: 2.5+"
	label values samp samplbl
	save ${dir_dta}\full_exper, replace
restore

preserve
	keep if eligible_sem1==1
	collapse (mean) grade normgrade (count) num_obs=grade [aweight= credithour], by(evergreek exper)
	gen samp = 3 if evergreek ==1 
	replace samp = 4 if evergreek ==0
	label var samp "Description of sample - Greek X GPA req"
	label values samp samplbl
	append using "${dir_dta}\full_exper.dta"
	graph twoway (scatter grade exper if exper <=7 & samp==3,  connect(1) lpattern(dash)) ///
	(scatter grade exper if exper <=7 & samp==2,  connect(1)) ///
	(scatter grade exper if exper <=7 & samp==4,  connect(1)),  xlabel(0 2 4 6) ///
	ytitle("GPA") xtitle("Semesters of experience") legend(label(1 "Ever-Greek - Eligible") label(2 "Never-Greek - Full Sample") label(3 "Never-Greek - Eligible")) ///
	note("") 
	graph save ${dir_gph}\fig3.gph, replace
	graph export ${dir_gph}\fig3.pdf, replace
	*title("Figure 1: GPA Profile of Treatment" "and Comparison Groups") 
restore

/*==================================================================================
EVENT GRAPH -- FIGURE 4
==================================================================================*/
preserve
gen pledget=exper-exp_at_pledge
cap drop z
gen z=cum_gpa if exper==2
bysort dummyid: egen cum_gpa2=mean(z)
drop z
keep if eligible_sem1==1
tab pledget
sum pledget
local minpledget=r(min)
local maxpledget=r(max)
local tspan=`maxpledget'-`minpledget'+1
display `minpledget' "  " `maxpledget'
replace pledget=pledget-`minpledget' /*set min of pledget to 0*/
bysort dummyid: egen maxexper=max(exper)

forvalues e=0/`tspan' {
gen p`e'=(exp_at_pledge~=.)*(pledget==`e')
}
local t_at_pledge=-`minpledget'-1
display `t_at_pledge'
drop p`t_at_pledge'
areg normgrade  i.exper p0-p`tspan' if exper<12 & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid) base
eststo est1
test p0=p1=0
estadd scalar p1=r(p)
esttab est1 using ${dir_results}\normgrade_regs_pledge3, scalars(p1) replace

parmest, saving("${dir_dta}\temp1", replace) 
 use "${dir_dta}\temp1", clear
 keep if substr(parm,1,1)=="p"
 rename t tstat
 gen t=real(substr(parm,2,2))+`minpledget'
 drop if t>6
 drop if t<-3
 local nn=_N+1
 set obs `nn'
 replace t =-1 if _n==`nn'
 replace estimate=0 if _n==`nn'
 replace min95=0 if _n==`nn'
 replace max95=0 if _n==`nn'
 sort t
 do "${dir_do}\graph_settings.do"
 keep if t<5
 twoway  (rcap min95 max95 t, color(black) ) (scatter estimate t, legend(off) color(black) xtitle(Semesters relative to pledge semester.) xlabel(-3(1)4) ytitle(Estimated Effect) yline(0) ///
		title("") ///
		note(""))
 
  graph save "${dir_gph}\fig4.gph", replace
  graph export "${dir_gph}\fig4.pdf", replace

  
 restore


/*==================================================================================
	Table 4.  Effect of Greek Affiliation on Grades.  
==================================================================================*/
preserve
forvalues f=0/1 {
areg normgrade grk $x  if exper<12 & female==`f' [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo newspec1_`f'

areg normgrade grk $x  if exper<12 & female==`f' & eligible_sem1==1 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo newspec2_`f'

reghdfe grade grk $x  if exper<12 & female==`f' [aw=credithours], absorb(dummyid courseid) cluster(dummyid courseid)
eststo newspec3_`f'

reghdfe grade grk $x  if exper<12 & female==`f' & eligible_sem1==1 [aw=credithours], absorb(dummyid courseid) cluster(dummyid courseid)
eststo newspec4_`f'



}
restore
capture erase "${dir_results}\table4.rtf"
esttab newspec1_1 newspec2_1  newspec3_1 newspec4_1 using ${dir_results}\table4.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	replace mtitles("Full Sample, Normalized Grades" "2.5+ GPA in Sem1, Normalized Grades" "Full Sample, Actual Grades"  "2.5+ in Sem1, Actual Grades." ) ///
	keep(grk*) label
	
esttab newspec1_0 newspec2_0  newspec3_0 newspec4_0 using ${dir_results}\table4.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	append  mtitles("Full Sample, Normalized Grades" "2.5+ GPA in 1st Semester, Normalized Grades" "Full Sample, Actual Grades"  "2.5+ GPA in 1st Semester, Actual Grades." ) ///
	keep(grk*) label	title("Table 4." ) ///
	addnotes("Dependent variable is normalized course grade  in specifications (1) and (2)  and the actual grade (ranging" ///
	"from 0 to 4) in specifications 3 and 4.   Sepcifications (2) and (4) restrict the sample to students with a GPA of 2.5 or" /// 
	"above at the end of the first semester since this is the sample of students eligible to pledge in the second semester." /// 
	"All regressions are weighted by credit hour and include student and semesters of experience fixed effects.  The models" ///
	"using actual grades also include course fixed effects.")
	

/*==================================================================================
	Table 5.  Dynamic Effects of Greek Affiliation on Grades, Course Credits and Course Difficulty.  
==================================================================================*/
preserve
global grk_vars  grk_pledge grk_active grk_former
global x i.exper i.hterm
bysort dummyid term: gen obs=_n

forvalues f=0/1 {
areg normgrade ${grk_vars} $x  if exper<12 & female==`f' & eligible_sem1==1 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec1_`f'
areg courseavg_i $grk_vars $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec2_`f'
areg courselevel $grk_vars $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec3_`f'
areg withdraw $grk_vars $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec4_`f'
areg  complete_cred $grk_vars $x  if exper<12 & female==`f' & obs==1 & eligible_sem1==1 , absorb(dummyid) cluster(dummyid)  /*restricting to obs=1 keeps one obs per student/term*/
eststo spec5_`f'
}
capture erase "${dir_results}\table5.rtf"
esttab spec1_1 spec2_1 spec3_1 spec4_1 spec5_1 using ${dir_results}\table5.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	replace title(Table 5.  Females.) mtitles("Normalized Grades"  "Average Grade for Course"  "Level of Course" "Withdraw"  "Course Credits Completed") ///
	keep(grk*) label
	
esttab spec1_0 spec2_0 spec3_0 spec4_0 spec5_0 using ${dir_results}\table5.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  append ///
	keep(grk*) label	title("Table 5.  Males" ) ///
	addnotes("")
restore

/*==================================================================================
	Table A8.  Dynamic Effects of Greek Affiliation on Grades, Course Credits and Course Difficulty.  
==================================================================================*/
preserve
global grk_vars  grk_pledge grk_active grk_former
global x i.exper i.hterm
bysort dummyid term: gen obs=_n


forvalues f=0/1 {
areg normgrade ${grk_vars} i1.spring#(i1.grk_active i1.grk_former) $x  if exper<12 & female==`f' & eligible_sem1==1 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec1_`f'
areg courseavg_i $grk_vars  i1.spring#(i1.grk_active i1.grk_former) $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec2_`f'
areg courselevel $grk_vars i1.spring#(i1.grk_active i1.grk_former) $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec3_`f'
areg withdraw $grk_vars i1.spring#(i1.grk_active i1.grk_former) $x if exper<12 & female==`f'  & eligible_sem1==1 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec4_`f'
areg  complete_cred $grk_vars i1.spring#(i1.grk_active i1.grk_former) $x  if exper<12 & female==`f' & obs==1 & eligible_sem1==1 , absorb(dummyid) cluster(dummyid)  /*restricting to obs=1 keeps one obs per student/term*/
eststo spec5_`f'

}
capture erase "${dir_results}\tablea5.rtf"
esttab spec1_1 spec2_1 spec3_1 spec4_1 spec5_1 using ${dir_results}\tablea8.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	replace title(Table A5.  Females.)mtitles("Normalized Grades"  "Average Grade for Course"  "Level of Course" "Course Withdraw" "Course Credits Completed") ///
	keep(grk* *spring*) label
	
esttab spec1_0 spec2_0 spec3_0 spec4_0 spec5_0 using ${dir_results}\tablea8.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  append ///
	keep(grk* *spring*) label	title("Table 5.  Males" ) ///
	addnotes("")
restore

/*==================================================================================
	Table 6.  Greek Effects on Grades:  Heterogeneity Across Students.
==================================================================================*/

preserve
global x i.exper i.hterm
drop if inelig_ch==1

forvalues f=0/1 {

areg normgrade grk $x  if exper<12 & female==`f' & cum_gpa_sem1>=2.5 & cum_gpa_sem1<=3.0 [aw=credithours] , absorb(dummyid) cluster(dummyid)
eststo spec1_`f'

areg normgrade grk $x  if exper<12 & female==`f' & cum_gpa_sem1>3.0 & cum_gpa_sem1<=3.30  [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec2_`f'

areg normgrade grk $x  if exper<12 & female==`f' & cum_gpa_sem1>3.3 & cum_gpa_sem1<=3.65  [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec3_`f'

areg normgrade grk $x  if exper<12 & female==`f' & cum_gpa_sem1>=3.65 & cum_gpa_sem1<.  [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec4_`f'

areg normgrade grk i1.grk#i1.low_act $x  if exper<12 & female==`f' & cum_gpa_sem1>=2.5  [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec5_`f'

areg normgrade grk i1.grk#i1.need_hi_med $x  if exper<12 & female==`f' & cum_gpa_sem1>=2.5  [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec6_`f'


}

capture erase "${dir_results}\table6.rtf"
esttab spec1_1 spec2_1 spec3_1 spec4_1 spec5_1 spec6_1  using ${dir_results}\table6.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	replace mtitles("[2.5,3.0]"  "()3.0,3.30]"  "(3.30,3.65]"  "(3.65,4.0]"  "[2.5,4.0]" "[2.5,4.0]" )  title(Table 6.  Greek Effects on Grades:  Heterogeneity Across Students.  Females.) ///
	keep(grk* *need* *low_act*) label ///
	
esttab spec1_0 spec2_0 spec3_0 spec4_0 spec5_0 spec6_0  using ${dir_results}\table6.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  append ///
	replace mtitles("[2.5,3.0]"  "()3.0,3.30]"  "(3.30,3.65]"  "(3.65,4.0]"  "[2.5,4.0]" "[2.5,4.0]" )  title(Table 6.  Greek Effects on Grades:  Heterogeneity Across Students.  Males.) ///
	keep(grk* *need* *low_act* ) label ///
	addnotes("")
restore

/*==================================================================================
	Table 7.  Greek Effects on Grades: Heterogeneity Across Chapters.
==================================================================================*/
preserve 
 use "${dir_dta}\cumgpa_dist_by_chapter.dta", clear
sum if female==1, d
return list
scalar p25f=r(p25)
scalar p75f=r(p75)
sum if female==0, d
scalar p25m=r(p25)
scalar p75m=r(p75)
display  p25f p75f p25m p75m
restore

preserve
egen nsibs_mn=mean(nsibs)
gen nsibs_dev=(nsibs-nsibs_mn)/100
replace nsibs_dev=0 if nsibs==0
label variable nsibs_dev "#sibs (100s) as dev from mean"
egen nsibs_course_mn=mean(nsibs_course)
gen nsibs_course_dev=(nsibs_course-nsibs_course_mn)
replace nsibs_course_dev=0 if nsibs_course==0
egen coursen_mn=mean(coursen)
gen coursen_dev=(coursen-coursen_mn)/100
areg normgrade grk c.nsibs*dev#i1.grk  coursen_dev $x if exper<12 & female==1 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec1
areg normgrade grk c.nsibs*dev#i1.grk  coursen_dev $x if exper<12 & female==0 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec2


gen mid50=0
replace mid50=1 if cumgpa_at_pledge>p25f & cumgpa_at_pledge<p75f & female==1
replace mid50=1 if cumgpa_at_pledge>p25m & cumgpa_at_pledge<p75m & female==0
gen top25=0
replace top25=1 if cumgpa_at_pledge>=p75f & cumgpa_at_pledge<. & female==1
replace top25=1 if cumgpa_at_pledge>=p75m & cumgpa_at_pledge<. & female==0

keep if eligible_sem1==1
areg normgrade grk (i1.mid50 i1.top25)#i1.grk $x if exper<12 & female==1 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec3
areg normgrade grk (i1.mid50 i1.top25)#i1.grk  $x if exper<12 & female==0 [aw=credithours], absorb(dummyid) cluster(dummyid)
eststo spec4

esttab  spec1 spec2 spec3 spec4  using ${dir_results}\table7.rtf, b(3) se(3) star(* .10 ** .05 *** .01)  ///
	replace mtitles("Females" "Males"  "Females" "Males") ///
	keep(*sibs* *grk* coursen_dev) label ///
	title("Table 7. Greek Effects on Grades: Heterogeneity Across Chapters.") 
restore


 
